
## 0.2.0

* Provide `add_verbosity_flag` function, as an alternate method to enable '-vv' in CLI tools.

## 0.1.0

* Enable pretty console logging for an entire package.
* Provide argparse 'parent parser' solution, enabling '-vv' in CLI tools.